<?php
namespace Bushelpowered\Api\Trade\Esign\V1\Request;
        
class AutomatedCreateDocumentRequest implements \Bushelpowered\Api\Trade\Esign\V1\Request\CreateDocumentWithEncodedPdf
{
    /** @var string $erpId The id of the contract in the customer's ERP*/
    public string $erpId;
    /** @var null|string $erpVersion The version number of the contract. If erpId matches an existing contract, having a different version will create an amendment.*/
    public ?string $erpVersion = null;
    /** @var null|string $erpPricingType Another separate version number for the contract. If erpId matches an existing contract, having a different version will create an amendment.*/
    public ?string $erpPricingType = null;
    /** @var string $senderName The name of the sender of this contract.*/
    public string $senderName;
    /** @var string $senderEmail The email of the sender of this contract.*/
    public string $senderEmail;
    /** @var \Bushelpowered\Api\Trade\Esign\V1\Model\SignatureBox[] $signatureBoxes The signature boxes to be placed on the document.*/
    public array $signatureBoxes;
    /** @var string $displayId The name of the contract that will show to the grower in the esign list view.*/
    public string $displayId;
    /** @var string $file The PDF of the document base64 encoded.*/
    public string $file;

    /**
     * @param  string  $erpId The id of the contract in the customer's ERP
     * @param  null|string  $erpVersion The version number of the contract. If erpId matches an existing contract, having a different version will create an amendment.
     * @param  null|string  $erpPricingType Another separate version number for the contract. If erpId matches an existing contract, having a different version will create an amendment.
     * @param  string  $senderName The name of the sender of this contract.
     * @param  string  $senderEmail The email of the sender of this contract.
     * @param  \Bushelpowered\Api\Trade\Esign\V1\Model\SignatureBox[]  $signatureBoxes The signature boxes to be placed on the document.
     * @param  string  $displayId The name of the contract that will show to the grower in the esign list view.
     * @param  string  $file The PDF of the document base64 encoded.
     */
    public function __construct(string $erpId, ?string $erpVersion, ?string $erpPricingType, string $senderName, string $senderEmail, array $signatureBoxes, string $displayId, string $file)
    {
        $this->erpId = $erpId;
        $this->erpVersion = $erpVersion;
        $this->erpPricingType = $erpPricingType;
        $this->senderName = $senderName;
        $this->senderEmail = $senderEmail;
        $this->signatureBoxes = $signatureBoxes;
        $this->displayId = $displayId;
        $this->file = $file;
    }
    
    /**
     * @return string The name of the contract that will show to the grower in the esign list view.
     */
    public function getDisplayId(): string
    {
        return $this->displayId;
    }
    /**
     * @return string The PDF of the document base64 encoded.
     */
    public function getFile(): string
    {
        return $this->file;
    }
}