<?php
namespace Bushelpowered\Api\Trade\Esign\V1\Request;
        
class CreateDocumentRequest implements \Bushelpowered\Api\Trade\Esign\V1\Request\CreateDocumentWithEncodedPdf
{
    /** @var string $datasourceId The id of the datasource where this record came from.*/
    public string $datasourceId;
    /** @var null|string $title The title of the document.*/
    public ?string $title = null;
    /** @var null|string $subject The subject of the document.*/
    public ?string $subject = null;
    /** @var null|string $message The message of the document.*/
    public ?string $message = null;
    /** @var \Bushelpowered\Api\Trade\Esign\V1\Model\Owner $owner */
    public \Bushelpowered\Api\Trade\Esign\V1\Model\Owner $owner;
    /** @var \Bushelpowered\Api\Trade\Esign\V1\Model\Signer $signer */
    public \Bushelpowered\Api\Trade\Esign\V1\Model\Signer $signer;
    /** @var bool $isSigned Whether or not the document is signed by the creator.*/
    public bool $isSigned;
    /** @var string $displayId The name of the contract that will show to the grower in the esign list view.*/
    public string $displayId;
    /** @var string $file The PDF of the document base64 encoded.*/
    public string $file;

    /**
     * @param  string  $datasourceId The id of the datasource where this record came from.
     * @param  null|string  $title The title of the document.
     * @param  null|string  $subject The subject of the document.
     * @param  null|string  $message The message of the document.
     * @param  \Bushelpowered\Api\Trade\Esign\V1\Model\Owner  $owner 
     * @param  \Bushelpowered\Api\Trade\Esign\V1\Model\Signer  $signer 
     * @param  bool  $isSigned Whether or not the document is signed by the creator.
     * @param  string  $displayId The name of the contract that will show to the grower in the esign list view.
     * @param  string  $file The PDF of the document base64 encoded.
     */
    public function __construct(string $datasourceId, ?string $title, ?string $subject, ?string $message, \Bushelpowered\Api\Trade\Esign\V1\Model\Owner $owner, \Bushelpowered\Api\Trade\Esign\V1\Model\Signer $signer, bool $isSigned, string $displayId, string $file)
    {
        $this->datasourceId = $datasourceId;
        $this->title = $title;
        $this->subject = $subject;
        $this->message = $message;
        $this->owner = $owner;
        $this->signer = $signer;
        $this->isSigned = $isSigned;
        $this->displayId = $displayId;
        $this->file = $file;
    }
    
    /**
     * @return string The name of the contract that will show to the grower in the esign list view.
     */
    public function getDisplayId(): string
    {
        return $this->displayId;
    }
    /**
     * @return string The PDF of the document base64 encoded.
     */
    public function getFile(): string
    {
        return $this->file;
    }
}